// ----------------------------------------------------------------------------
//
//  Copyright (C) 2008-2017 Fons Adriaensen <fons@linuxaudio.org>
//    
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// ----------------------------------------------------------------------------


#ifndef __JCLIENT_H
#define __JCLIENT_H


#include <inttypes.h>
#include <stdlib.h>
#include <math.h>
#include <clthreads.h>
#include <jack/jack.h>
#include "gainctl.h"
#include "hp3filt.h"
#include "svparam2.h"
#include "global.h"


class Jclient : public A_thread
{
public:

    Jclient (const char *jname, const char *jserv, int nchan);
    ~Jclient (void);

    const char *jname (void) const { return _jname; }
    const int   fsamp (void) const { return _fsamp; }
    
    void set_hpfilt (bool act, float freq)
    {
	_hpfilt.setparam (act ? freq : 0.0f);
    }

    void set_equal (bool act, float gain)
    {
	_eqgain.setgain (act ? gain : 1.0f);
	for (int i = 0; i < 5; i++)
	{
	    _fsect [i]->bypass (!act);
	}
    }

    void set_param (int ind, float gain, float freq, float shape)
    {
	_fsect [ind]->setpars (freq, gain, shape);
    }

private:

    void  init_jack (const char *jname, const char *jserv);
    void  close_jack (void);
    void  jack_shutdown (void);
    int   jack_process (int nframes);

    virtual void thr_main (void) {}

    jack_client_t  *_jack_client;
    jack_port_t    *_inpports [MAXCH];
    jack_port_t    *_outports [MAXCH];
    bool            _active;
    const char     *_jname;
    int             _fsamp;
    int             _nchan;
    int             _fragm;
    int             _nsamp;
    Gainctl         _eqgain;
    HP3filt         _hpfilt;
    Svparam2       *_fsect [5];
  
    static void jack_static_shutdown (void *arg);
    static int  jack_static_process (jack_nframes_t nframes, void *arg);
};


#endif
