// ----------------------------------------------------------------------------
//
//  Copyright (C) 2008-2017 Fons Adriaensen <fons@linuxaudio.org>
//    
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// ----------------------------------------------------------------------------


#ifndef __MAINWIN_H
#define	__MAINWIN_H


#include <clxclient.h>
#include "guiclass.h"
#include "jclient.h"
#include "global.h"


class Mainwin : public A_thread, public X_window, public X_callback
{
public:

    enum { XSIZE = 640, YSIZE = 100 };

    Mainwin (X_rootwin *parent, X_resman *xres, int xp, int yp, Jclient *jclient);
    ~Mainwin (void);
    Mainwin (const Mainwin&);
    Mainwin& operator=(const Mainwin&);

    void stop (void) { _stop = true; }
    int process (void); 

private:

    enum { B_HPF, B_EQU };
    enum
    {
	HPFIL,
        EGAIN,
        GAIN1, FREQ1, TYPE1,
        GAIN2, FREQ2, BNDW2,
        GAIN3, FREQ3, BNDW3,
        GAIN4, FREQ4, BNDW4,
        GAIN5, FREQ5, TYPE5,
	NROTARY
    };
 
    virtual void thr_main (void) {}

    void  handle_time (void);
    void  handle_stop (void);
    void  handle_event (XEvent *);
    void  handle_callb (int type, X_window *W, XEvent *E);
    void  expose (XExposeEvent *E);
    void  clmesg (XClientMessageEvent *E);
    void  redraw (void);
    void  fmtfreq (double v, char *s);
    float db2lin (float g);
    void  setparam (int k);

    Atom            _atom;
    bool            _stop;
    X_resman       *_xres;
    Jclient        *_jclient;
    int             _fsamp;
    PushButton     *_butt_hpf;
    PushButton     *_butt_equ;
    PushButton     *_butt_resp;
    PushButton     *_butt_pres;
    RotaryCtl      *_rotary [NROTARY];
    X_textip       *_tfreq [5];
    X_textip       *_tgain [5];
};


#endif
