// ----------------------------------------------------------------------------
//
//  Copyright (C) 2008-2017 Fons Adriaensen <fons@linuxaudio.org>
//    
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// ----------------------------------------------------------------------------


#include "styles.h"
#include "png2img.h"


XftColor      *XftColors [NXFTCOLORS];
XftFont       *XftFonts [NXFTFONTS];

X_textln_style tsfreq;
X_textln_style tsgain;

XImage    *mastersect;
XImage    *hfshfsect;
XImage    *parm1sect;
XImage    *parm2sect;
XImage    *parm3sect;
XImage    *lfshfsect;
XImage    *redzita;
XImage    *bhpfil;
XImage    *bequal;

RotaryGeom  rg_hpfil;
RotaryGeom  rg_mgain;
RotaryGeom  rg_sgain;
RotaryGeom  rg_sfreq;
RotaryGeom  rg_sbndw;


void styles_init (X_display *disp, X_resman *xrm)
{
    XftColors [C_MAIN_BG] = disp->alloc_xftcolor (0.25f, 0.25f, 0.25f, 1.0f);
    XftColors [C_MAIN_FG] = disp->alloc_xftcolor (1.00f, 1.00f, 1.00f, 1.0f);
    XftColors [C_MAIN_DL] = disp->alloc_xftcolor (0.40f, 0.40f, 0.40f, 1.0f);
    XftColors [C_GAIN_FG] = disp->alloc_xftcolor (1.00f, 0.70f, 0.20f, 1.0f);
    XftColors [C_FREQ_FG] = disp->alloc_xftcolor (0.70f, 0.70f, 1.00f, 1.0f);

    XftColors [C_PLOT_BG] = disp->alloc_xftcolor (1.00f, 1.00f, 1.00f, 1.0f);
    XftColors [C_PLOT_FG] = disp->alloc_xftcolor (0.00f, 0.00f, 0.00f, 1.0f);
    XftColors [C_PLOT_GR] = disp->alloc_xftcolor (0.90f, 0.90f, 0.90f, 1.0f);
    XftColors [C_PLOT_T1] = disp->alloc_xftcolor (1.00f, 0.00f, 0.00f, 1.0f);
    XftColors [C_PLOT_T2] = disp->alloc_xftcolor (0.00f, 0.00f, 1.00f, 1.0f);

//    XftColors [C_PLOT_BG] = disp->alloc_xftcolor (0.25f, 0.25f, 0.25f, 1.0f);
//    XftColors [C_PLOT_FG] = disp->alloc_xftcolor (0.90f, 0.90f, 0.90f, 1.0f);
//    XftColors [C_PLOT_GR] = disp->alloc_xftcolor (0.30f, 0.30f, 0.30f, 1.0f);

    XftFonts [F_TEXT] = disp->alloc_xftfont (xrm->get (".font.text", "luxi:bold:pixelsize=10"));
    XftFonts [F_PLOT] = disp->alloc_xftfont (xrm->get (".font.plot", "luxi:pixelsize=9"));

    tsfreq.font = XftFonts [F_TEXT];
    tsfreq.color.normal.bgnd = XftColors [C_MAIN_BG]->pixel;
    tsfreq.color.normal.text = XftColors [C_FREQ_FG];

    tsgain.font = XftFonts [F_TEXT];
    tsgain.color.normal.bgnd = XftColors [C_MAIN_BG]->pixel;
    tsgain.color.normal.text = XftColors [C_GAIN_FG];

    mastersect = png2img (SHARED"/master.png", disp, XftColors [C_MAIN_BG]);
    hfshfsect = png2img (SHARED"/hfshelf.png", disp, XftColors [C_MAIN_BG]); 
    parm1sect = png2img (SHARED"/param1.png",  disp, XftColors [C_MAIN_BG]);
    parm2sect = png2img (SHARED"/param2.png",  disp, XftColors [C_MAIN_BG]);
    parm3sect = png2img (SHARED"/param3.png",  disp, XftColors [C_MAIN_BG]);
    lfshfsect = png2img (SHARED"/lfshelf.png", disp, XftColors [C_MAIN_BG]);
    redzita = png2img (SHARED"/redzita.png", disp, XftColors [C_MAIN_BG]);
    bhpfil = png2img (SHARED"/bhpfil.png", disp, XftColors [C_MAIN_BG]);
    bequal = png2img (SHARED"/bequal.png", disp, XftColors [C_MAIN_BG]);

    if (   !mastersect
        || !hfshfsect
        || !parm1sect
        || !parm2sect
        || !parm3sect
        || !lfshfsect
        || !redzita
        || !bhpfil
        || !bequal)
    {
	fprintf (stderr, "Can't load images from '%s'.\n", SHARED);
	exit (1);
    }

    rg_hpfil._backg = XftColors [C_MAIN_BG];
    rg_hpfil._image [0] = mastersect;
    rg_hpfil._lncol [0] = 1;
    rg_hpfil._x0 = 48;
    rg_hpfil._y0 = 8;
    rg_hpfil._dx = 25;
    rg_hpfil._dy = 25;
    rg_hpfil._xref = 12.5;
    rg_hpfil._yref = 12.5;
    rg_hpfil._rad = 12;

    rg_mgain._backg = XftColors [C_MAIN_BG];
    rg_mgain._image [0] = mastersect;
    rg_mgain._lncol [0] = 0;
    rg_mgain._x0 = 48;
    rg_mgain._y0 = 59;
    rg_mgain._dx = 25;
    rg_mgain._dy = 25;
    rg_mgain._xref = 12.5;
    rg_mgain._yref = 12.5;
    rg_mgain._rad = 12;

    rg_sgain._backg = XftColors [C_MAIN_BG];
    rg_sgain._image [0] = lfshfsect;
    rg_sgain._lncol [0] = 0;
    rg_sgain._x0 = 59;
    rg_sgain._y0 = 17;
    rg_sgain._dx = 25;
    rg_sgain._dy = 25;
    rg_sgain._xref = 12.5;
    rg_sgain._yref = 12.5;
    rg_sgain._rad = 12;
 
    rg_sfreq._backg = XftColors [C_MAIN_BG];
    rg_sfreq._image [0] = lfshfsect;
    rg_sfreq._lncol [0] = 1;
    rg_sfreq._x0 = 12;
    rg_sfreq._y0 = 37;
    rg_sfreq._dx = 25;
    rg_sfreq._dy = 25;
    rg_sfreq._xref = 12.5;
    rg_sfreq._yref = 12.5;
    rg_sfreq._rad = 12;

    rg_sbndw._backg = XftColors [C_MAIN_BG];
    rg_sbndw._image [0] = parm1sect;
    rg_sbndw._lncol [0] = 0;
    rg_sbndw._x0 = 59;
    rg_sbndw._y0 = 62;
    rg_sbndw._dx = 25;
    rg_sbndw._dy = 25;
    rg_sbndw._xref = 12.5;
    rg_sbndw._yref = 12.5;
    rg_sbndw._rad = 12;
}


void styles_fini (X_display *disp)
{
}
